@@ -14,8 +14,10 @@ ELU <- function(x, data, fun, dfun, prior, dprior, tol) {
                 "Mean of EL weights is not close enough to 1.")
   }
 
-  u <- - log(density) - sum(log(el$wts / length(el$wts)))
+  
+  u <- - density - sum(log(el$wts / length(el$wts)))
 
+  
   dellogL <- array(0, c(length(el$wts), length(x)))
   for (i in 1:NROW(data)) {
     dellogL[i, ] <- el$wts[i] * t(as.matrix(el$lambda)) %*% fun.gradients[, , i]
